<?php
/**
 * Login.php.
 *
 * Created By: jonathan
 * Date: 12/10/2020
 * Time: 10:05
 */

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class LoginController extends Controller
{
    public function login(Request $request)
    {
        $cred = $request->only('email', 'password');

        Auth::attempt($cred);
        $user = Auth::user();
        $userCollectivityAccess = true;

        if (!isset($user->role)) {
            abort(403, 'Votre email ou mot de passe est incorrect');
        }

        // Control if collectivity of user is active
        if (($user->role > 0) && $user->organization && (0 === $user->organization['active'])) {
            $userCollectivityAccess = false;
        }

        if ($user && $user->active && $userCollectivityAccess) {
            $user->last_login = Carbon::now();
            $user->save();
            $token = $user->createToken('token-name');

            return $token->plainTextToken;
        }

        if (($user && !$user->active) || !$userCollectivityAccess) {
            abort(403, "Compte inactif. Veuillez vous rapprocher d'un administrateur.");
        }

        Auth::logout();

        abort(403, 'Votre email ou mot de passe est incorrect');
    }

    public function impersonate(Request $request)
    {
        $id = (int) $request->id;
        $currentUser = Auth::user();

        if ($currentUser /* && $currentUser->active */ && User::ROLE_ADMIN === $currentUser->role) {
            $user = User::find($id);

            $token = $user->createToken('token-name');
            $currentUser->impersonate($user);

            return $token->plainTextToken;
        }

        abort(403);
    }

    public function leaveImpersonation()
    {
        Auth::user()->leaveImpersonation();
    }
}
