<?php

namespace App\Models;

use DateTime;
use Illuminate\Database\Eloquent\Concerns\HasTimestamps;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;

/**
 * Class Evaluation.
 *
 * @property int      $id
 * @property DateTime $createdAt
 * @property DateTime $updatedAt
 * @property [DangerLevel]|iterable $dangerLevels
 * @property [DangerLevel]|iterable $danger_levels
 * @property [EvaluationMeasure]|iterable $evaluationMeasures
 * @property [EvaluationMeasure]|iterable $evaluation_measures
 * @property string       $status
 * @property Organization $organization
 * @property int          $organization_id
 * @property int          $current_step
 * @property int          $current_step_status
 * @property string       $author
 * @property string       $updated_by
 */
class Evaluation extends Model
{
    use HasFactory;
    use HasTimestamps;

    public const STATUS_WAIT = 1;
    public const STATUS_ONGOING = 2;
    public const STATUS_DONE = 3;

    public const STATUS = [
        self::STATUS_WAIT => 'En attente',
        self::STATUS_ONGOING => 'En cours',
        self::STATUS_DONE => 'Terminé',
    ];

    public function dangerLevels(): BelongsToMany
    {
        return $this->belongsToMany(DangerLevel::class, 'danger_level_evaluation');
    }

    public function evaluationMeasures(): HasMany
    {
        return $this->hasMany(EvaluationMeasure::class);
    }

    public function organization(): BelongsTo
    {
        return $this->belongsTo(Organization::class);
    }
}
