<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Concerns\HasTimestamps;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;

/**
 * @property int     $id
 * @property string  $name
 * @property string  $short_name
 * @property string  $type
 * @property string  $siren
 * @property bool    $active
 * @property string  $website
 * @property string  $info
 * @property Address $address
 * @property Contact $referent
 * @property int     $referent_id
 * @property Contact $referent_cyber
 * @property Contact $referentCyber
 * @property int     $referent_cyber_id
 * @property Contact $referent_elu
 * @property Contact $referentElu
 * @property int     $referent_elu_id
 * @property [Evaluation]|iterable $evaluations
 */
class Organization extends Model
{
    use HasFactory;
    use HasTimestamps;

    public function users(): HasMany
    {
        return $this->hasMany(User::class);
    }

    public function evaluations(): HasMany
    {
        return $this->hasMany(Evaluation::class);
    }

    public function address(): BelongsTo
    {
        return $this->belongsTo(Address::class);
    }

    public function referent(): BelongsTo
    {
        return $this->belongsTo(Contact::class, 'referent_id');
    }

    public function referentCyber(): BelongsTo
    {
        return $this->belongsTo(Contact::class, 'referent_cyber_id');
    }

    public function referentElu(): BelongsTo
    {
        return $this->belongsTo(Contact::class, 'referent_elu_id');
    }
}
