import axios from 'axios';
import toaster from '../utils/toaster.js';

export default {
    state: { all: [], errors: null},
    mutations: {
        setOrganizations (state, items) {
            state.all = items;
        },
        updateOrganization (state, item) {
            let index = state.all.findIndex(s => s.id == item.id)
            state.all = state.all.filter(s => s.id != item.id)
            state.all.splice(index, 0, item)
        },
        deleteOrganization (state, item) {
            state.all = state.all.filter(u => u.id != item.id)
        },
        setErrors(state, errors) {
            state.errors = errors
        }
    },
    actions: {
        getOrganizations( {commit} ) {
            const req = axios.get(`/api/organizations`);
            req.then(res => {
                commit('setOrganizations', res.data);
            }).catch(err => {
                console.log('could not get users', err)
            })
            return req;
        },
        updateOrganization( {commit}, item ) {
            const req = item.id ? axios.put(`/api/organizations/${item.id}`, item) : axios.post(`/api/organizations`, item);
            req.then(res => {
                commit('updateOrganization', res.data);
                toaster(this._vm, 'Mise à jour effectuée', 'bg-success', 'check' )
            }).catch(err => {
                console.log('could not update org', err)
                commit('setErrors', {errors: err.response.data, status: err.response.status})
            })
            return req;
        },
        deleteOrganization( {commit}, org ) {
            console.log('deleteOrganization', org)
            const req = axios.delete(`/api/organizations/${org.id}`, org);
            req.then(res => {
                commit('deleteOrganization', org);
            }).catch(err => {
                console.log('could not delete org', err)
            })
            return req;
        }
    }

};
